Set severity for PELs
This commit adds an option to pass severity while logging PEL.
This will help to classify PELs based on their severity.
By default severity of all the PELs logged for system VPD failure
is set to be unrecoverable where as other failures are flagged as
predictive errors.
Signed-off-by: Sunny Srivastava <sunnsr25@in.ibm.com>
Change-Id: I9cd10a29252a42f5031b91b9c7ad2e284ed5b861
diff --git a/ibm_vpd_utils.hpp b/ibm_vpd_utils.hpp
index e21f13d..9b48021 100644
--- a/ibm_vpd_utils.hpp
+++ b/ibm_vpd_utils.hpp
@@ -66,11 +66,12 @@
/**
* @brief API to create PEL entry
* @param[in] Map holding the additional data
* @param[in] error interface
*/
void createPEL(const std::map<std::string, std::string>& additionalData,
- const std::string& errIntf);
+ const constants::PelSeverity& sev, const std::string& errIntf);
/**
* @brief getVpdFilePath
@@ -66,11 +66,12 @@
/**
* @brief API to create PEL entry
- * @param[in] Map holding the additional data
- * @param[in] error interface
+ * @param[in] additionalData - Map holding the additional data
+ * @param[in] sev - Severity
+ * @param[in] errIntf - error interface
*/
void createPEL(const std::map<std::string, std::string>& additionalData,